==> owncloud-4.0.4.tgz: owncloud/apps/files/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "هیچ خطایی وجود ندارد فایل با موفقیت بار گذاری شد",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حداکثر حجم تعیین شده برای بارگذاری در php.ini قابل ویرایش است",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حداکثر حجم مجاز برای بارگذاری از طریق HTML \nMAX_FILE_SIZE",
"The uploaded file was only partially uploaded" => "مقدار کمی از فایل بارگذاری شده",
"No file was uploaded" => "هیچ فایلی بارگذاری نشده",
"Missing a temporary folder" => "یک پوشه موقت گم شده است",
"Failed to write to disk" => "نوشتن بر روی دیسک سخت ناموفق بود",
"Files" => "فایل ها",
"Size" => "اندازه",
"Modified" => "تغییر یافته",
"File handling" => "اداره پرونده ها",
"Maximum upload size" => "حداکثر اندازه بارگزاری",
"max. possible: " => "حداکثرمقدارممکن:",
"Needed for multi-file and folder downloads." => "احتیاج پیدا خواهد شد برای چند پوشه و پرونده",
"Enable ZIP-download" => "فعال سازی بارگیری پرونده های فشرده",
"0 is unlimited" => "0 نامحدود است",
"Maximum input size for ZIP files" => "حداکثرمقدار برای بار گزاری پرونده های فشرده",
"New" => "جدید",
"Text file" => "فایل متنی",
"Folder" => "پوشه",
"From url" => "از نشانی",
"Upload" => "بارگذاری",
"Cancel upload" => "متوقف کردن بار گذاری",
"Nothing in here. Upload something!" => "اینجا هیچ چیز نیست.",
"Name" => "نام",
"Share" => "به اشتراک گذاری",
"Download" => "بارگیری",
"Delete" => "پاک کردن",
"Upload too large" => "حجم بارگذاری بسیار زیاد است",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
"Files are being scanned, please wait." => "پرونده ها در حال بازرسی هستند لطفا صبر کنید",
"Current scanning" => "بازرسی کنونی"
);

==> owncloud-4.5.7.tgz: owncloud/apps/files/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "هیچ خطایی وجود ندارد فایل با موفقیت بار گذاری شد",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حداکثر حجم تعیین شده برای بارگذاری در php.ini قابل ویرایش است",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حداکثر حجم مجاز برای بارگذاری از طریق HTML \nMAX_FILE_SIZE",
"The uploaded file was only partially uploaded" => "مقدار کمی از فایل بارگذاری شده",
"No file was uploaded" => "هیچ فایلی بارگذاری نشده",
"Missing a temporary folder" => "یک پوشه موقت گم شده است",
"Failed to write to disk" => "نوشتن بر روی دیسک سخت ناموفق بود",
"Files" => "فایل ها",
"Delete" => "پاک کردن",
"already exists" => "وجود دارد",
"replace" => "جایگزین",
"cancel" => "لغو",
"replaced" => "جایگزین‌شده",
"undo" => "بازگشت",
"with" => "همراه",
"deleted" => "حذف شده",
"generating ZIP-file, it may take some time." => "در حال ساخت فایل فشرده ممکن است زمان زیادی به طول بیانجامد",
"Unable to upload your file as it is a directory or has 0 bytes" => "ناتوان در بارگذاری یا فایل یک پوشه است یا 0بایت دارد",
"Upload Error" => "خطا در بار گذاری",
"Pending" => "در انتظار",
"Upload cancelled." => "بار گذاری لغو شد",
"Invalid name, '/' is not allowed." => "نام نامناسب '/' غیرفعال است",
"Name" => "نام",
"Size" => "اندازه",
"Modified" => "تغییر یافته",
"folder" => "پوشه",
"folders" => "پوشه ها",
"file" => "پرونده",
"files" => "پرونده ها",
"File handling" => "اداره پرونده ها",
"Maximum upload size" => "حداکثر اندازه بارگزاری",
"max. possible: " => "حداکثرمقدارممکن:",
"Needed for multi-file and folder downloads." => "احتیاج پیدا خواهد شد برای چند پوشه و پرونده",
"Enable ZIP-download" => "فعال سازی بارگیری پرونده های فشرده",
"0 is unlimited" => "0 نامحدود است",
"Maximum input size for ZIP files" => "حداکثرمقدار برای بار گزاری پرونده های فشرده",
"New" => "جدید",
"Text file" => "فایل متنی",
"Folder" => "پوشه",
"From url" => "از نشانی",
"Upload" => "بارگذاری",
"Cancel upload" => "متوقف کردن بار گذاری",
"Nothing in here. Upload something!" => "اینجا هیچ چیز نیست.",
"Share" => "به اشتراک گذاری",
"Download" => "بارگیری",
"Upload too large" => "حجم بارگذاری بسیار زیاد است",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
"Files are being scanned, please wait." => "پرونده ها در حال بازرسی هستند لطفا صبر کنید",
"Current scanning" => "بازرسی کنونی"
);
